==> react-daily-components-0.5.4.tgz: package/lib/esm/components/inputs/DatePicker/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as Styled from "./style";
import { forwardRef, useCallback, useRef, useState } from "react";
import { Date, getCalendarDate } from "../../../types/date";
import { replaceAt } from "../../../utilities/string";
import useClickOutside from "../../../hooks/useClickOutside";
import useCursor from "../../../hooks/useCursor";
import ArrowButton from "../../common/ArrowButton";
import { getSizeProps } from "../../../utilities/props";
import useActive from "../../../hooks/useActive";
import Month from "./Month";
import Weekdays from "./Weekdays";
import Days from "./Days";
import { dispatchChange } from "../../../utilities/event";
var DatePicker = forwardRef(function (props, forwardedRef) {
    var weekdays = props.weekdays, _a = props.mondayFirst, mondayFirst = _a === void 0 ? true : _a, _b = props.weekendColor, weekendColor = _b === void 0 ? true : _b, value = props.value, onChange = props.onChange, _c = props.onClick, onClick = _c === void 0 ? function () { } : _c, _d = props.onFocus, onFocus = _d === void 0 ? function () { } : _d, _e = props.onSearch, onSearch = _e === void 0 ? function () { } : _e, listContainerStyle = props.listContainerStyle, listStyle = props.listStyle, itemStyle = props.itemStyle;
    var _f = useActive(), active = _f.active, setActive = _f.setActive, handleActive = _f.handleActive;
    var _g = useState(Date.string(value)), date = _g[0], setDate = _g[1];
    var containerRef = useRef(null);
    var inputRef = useRef(null);
    var setCursor = useCursor(inputRef, date).setCursor;
    useClickOutside(containerRef, setActive);
    /**
     * Click handler
     */
    var handleClick = useCallback(function (e, item) {
        onClick(e);
        setDate(item);
        handleDispatchChange(item.getString());
        setActive(false);
    }, []);
    /**
     * Change Handler
     */
    var handleChange = useCallback(function (e) {
        var event = e.nativeEvent;
        var target = e.target;
        var cursor = target === null || target === void 0 ? void 0 : target.selectionStart;
        var data = event.data;
        if (!cursor || !data)
            return;
        // only numbers are allowed
        if (isNaN(+data))
            return;
        // cursor positioned char is dash, replaced
        if (target.value.charAt(cursor) === "-") {
            target.value = replaceAt(target.value, cursor - 1, "");
            target.value = replaceAt(target.value, cursor, data);
            setCursor(cursor + 1);
        }
        else {
            target.value = replaceAt(target.value, cursor, "");
            setCursor(cursor);
        }
        setDate(Date.string(target.value));
        onSearch(e);
    }, []);
    /**
     * Focus handler
     */
    var handleFocus = useCallback(function (e) {
        setActive(true);
        onFocus(e);
    }, []);
    /**
     * Dispatch change
     */
    var handleDispatchChange = useCallback(function (value) {
        dispatchChange(containerRef, value);
    }, []);
    var style = __assign(__assign({}, getSizeProps(props)), props.style);
    return (_jsxs(Styled.Container, __assign({ ref: containerRef, active: active, style: style }, { children: [_jsx("input", { ref: forwardedRef, value: value, onChange: onChange, readOnly: true, hidden: true }), _jsx(Styled.Input, { ref: inputRef, value: date.getString(), onChange: handleChange, onFocus: handleFocus }), _jsx(ArrowButton, { onClick: handleActive, direction: active ? "Up" : "Down" }), _jsxs(Styled.ListContainer, __assign({ active: active, style: listContainerStyle }, { children: [_jsx(Month, { date: date, setDate: setDate }), _jsx(Weekdays, { weekdays: weekdays, mondayFirst: mondayFirst, weekendColor: weekendColor }), _jsx(Days, { calendar: getCalendarDate({ date: date, mondayFirst: mondayFirst }), date: date, onClick: handleClick, listStyle: listStyle, itemStyle: itemStyle })] }))] })));
});
export default DatePicker;

==> react-daily-components-0.5.6.tgz: package/lib/esm/components/inputs/DatePicker/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as Styled from "./style";
import { forwardRef, useCallback, useRef, useState } from "react";
import { Date, getCalendarDate } from "../../../types/date";
import { replaceAt } from "../../../utilities/string";
import useClickOutside from "../../../hooks/useClickOutside";
import useCursor from "../../../hooks/useCursor";
import ArrowButton from "../../common/ArrowButton";
import useActive from "../../../hooks/useActive";
import Month from "./Month";
import Weekdays from "./Weekdays";
import Days from "./Days";
import { dispatchChange } from "../../../utilities/event";
import { getStyleProps } from "../../../utilities/props";
var DatePicker = forwardRef(function (props, forwardedRef) {
    var weekdays = props.weekdays, _a = props.mondayFirst, mondayFirst = _a === void 0 ? true : _a, _b = props.weekendColor, weekendColor = _b === void 0 ? true : _b, value = props.value, onChange = props.onChange, _c = props.onClick, onClick = _c === void 0 ? function () { } : _c, _d = props.onFocus, onFocus = _d === void 0 ? function () { } : _d, _e = props.onSearch, onSearch = _e === void 0 ? function () { } : _e, listContainerStyle = props.listContainerStyle, listStyle = props.listStyle, itemStyle = props.itemStyle;
    var _f = useActive(), active = _f.active, setActive = _f.setActive, handleActive = _f.handleActive;
    var _g = useState(Date.string(value)), date = _g[0], setDate = _g[1];
    var containerRef = useRef(null);
    var inputRef = useRef(null);
    var setCursor = useCursor(inputRef, date).setCursor;
    useClickOutside(containerRef, setActive);
    /**
     * Click handler
     */
    var handleClick = useCallback(function (e, item) {
        onClick(e);
        setDate(item);
        handleDispatchChange(item.getString());
        setActive(false);
    }, []);
    /**
     * Change Handler
     */
    var handleChange = useCallback(function (e) {
        var event = e.nativeEvent;
        var target = e.target;
        var cursor = target === null || target === void 0 ? void 0 : target.selectionStart;
        var data = event.data;
        if (!cursor || !data)
            return;
        // only numbers are allowed
        if (isNaN(+data))
            return;
        // cursor positioned char is dash, replaced
        if (target.value.charAt(cursor) === "-") {
            target.value = replaceAt(target.value, cursor - 1, "");
            target.value = replaceAt(target.value, cursor, data);
            setCursor(cursor + 1);
        }
        else {
            target.value = replaceAt(target.value, cursor, "");
            setCursor(cursor);
        }
        setDate(Date.string(target.value));
        onSearch(e);
    }, []);
    /**
     * Focus handler
     */
    var handleFocus = useCallback(function (e) {
        setActive(true);
        onFocus(e);
    }, []);
    /**
     * Dispatch change
     */
    var handleDispatchChange = useCallback(function (value) {
        dispatchChange(containerRef, value);
    }, []);
    return (_jsxs(Styled.Container, __assign({ ref: containerRef, active: active, style: getStyleProps(props) }, { children: [_jsx("input", { ref: forwardedRef, value: value, onChange: onChange, readOnly: true, hidden: true }), _jsx(Styled.Input, { ref: inputRef, value: date.getString(), onChange: handleChange, onFocus: handleFocus }), _jsx(ArrowButton, { onClick: handleActive, direction: active ? "Up" : "Down" }), _jsxs(Styled.ListContainer, __assign({ active: active, style: listContainerStyle }, { children: [_jsx(Month, { date: date, setDate: setDate }), _jsx(Weekdays, { weekdays: weekdays, mondayFirst: mondayFirst, weekendColor: weekendColor }), _jsx(Days, { calendar: getCalendarDate({ date: date, mondayFirst: mondayFirst }), date: date, onClick: handleClick, listStyle: listStyle, itemStyle: itemStyle })] }))] })));
});
export default DatePicker;
